#
# spec file for package python-mkdocs-material
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-mkdocs-material
Version:        9.5.47
Release:        1.1
Summary:        Material theme for mkdocs
License:        MIT
URL:            https://squidfunk.github.io/mkdocs-material/
Source:         https://files.pythonhosted.org/packages/source/m/mkdocs_material/mkdocs_material-%{version}.tar.gz
# PATCH-FIX-OPENSUSE no-hatchling-requirements_txt.patch mcepl@suse.com
# Manually create project.dependencies in pyproject.toml instead of using
# hatch_requirements_txt module
# This is a brutal hack, but otherwise (see sr#1072844 for
# details) we need python-hatch_requirements_txt which pulls in
# excessive number of packages (starting with python-conincidence,
# python-whey, python-domdf-python-tools, and many others). Until
# we have these in openSUSE, we should stay with this
# hand-managed patch.
Patch0:         no-hatchling-requirements_txt.patch
BuildRequires:  %{python_module hatch_nodejs_version}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module trove-classifiers >= 2023.10.18}
# Requirements for core
# https://github.com/squidfunk/mkdocs-material/blob/master/requirements.txt#L21
BuildRequires:  %{python_module Jinja2 >= 3.1}
BuildRequires:  %{python_module Markdown >= 3.4}
BuildRequires:  %{python_module mkdocs >= 1.5.3 with %python-mkdocs < 2}
BuildRequires:  %{python_module mkdocs-material-extensions >= 1.3}
BuildRequires:  %{python_module pygments >= 2.16}
BuildRequires:  %{python_module pymdown-extensions >= 10.3}
# Requirements for plugins
# https://github.com/squidfunk/mkdocs-material/blob/master/requirements.txt#L29
BuildRequires:  %{python_module Babel >= 2.10}
BuildRequires:  %{python_module colorama >= 0.4}
BuildRequires:  %{python_module paginate >= 0.5}
BuildRequires:  %{python_module regex => 2023.8}
BuildRequires:  %{python_module requests >= 2.31}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# Requirements for core
# https://github.com/squidfunk/mkdocs-material/blob/master/requirements.txt#L21
Requires:       python-Jinja2 >= 3.1
Requires:       python-Markdown >= 3.4
Requires:       python-mkdocs-material-extensions >= 1.1
Requires:       python-pygments >= 2.16
Requires:       python-pymdown-extensions >= 10.3
Requires:       (python-mkdocs >= 1.5.3 with python-mkdocs < 2)
# Requirements for plugins
# https://github.com/squidfunk/mkdocs-material/blob/master/requirements.txt#L29
Requires:       python-Babel >= 2.10
Requires:       python-colorama >= 0.4
Requires:       python-paginate >= 0.5
Requires:       python-regex => 2023.8
Requires:       python-requests >= 2.31

BuildArch:      noarch
%python_subpackages

%description
Material theme for mkdocs

%prep
%autosetup -p1 -n mkdocs_material-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# no tests available upstream

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/material/
%{python_sitelib}/mkdocs_material-%{version}.dist-info/

%changelog
* Sun Dec  1 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.47:
  * Fixed #7750: Numeric tags break search
  * Fixed #7748: Blog plugin breaks when using future drafts
    (9.5.45 regression)
* Tue Nov 26 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.46:
  * Added support for removing preload hints in privacy plugin
  * Fixed #7734: Code blocks in h5 headlines are uppercased
  * Fixed #7725: Blog plugin crashing on missing timezone (9.5.45
    regression)
* Wed Nov 20 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.45:
  * Reduced size of Docker image through multi-stage build
  * Fixed #7708: Blog plugin crashing on YAML dates with timezones
* Tue Nov 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.44:
  * Fixed #7672: Font CSS 404's when using privacy
    plugin (9.5.43 regression)
* Thu Oct 31 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.43:
  * Added support for external images in SVGs in privacy plugin
  * Fixed #7651:
    Privacy plugin doesn't handle quoted URLs in CSS
* Tue Oct 22 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.42:
  * Fixed #7625: Invalid encoding of boolean attributes in privacy
    plugin
  * Fixed #7624: Crash when disabling privacy plugin (9.5.41
    regression)
* Tue Oct 15 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.41:
  * Fixed #7619: Improved tooltip on logo disappears after instant
    navigation
  * Fixed #7616: Race condition in built-in privacy plugin when
    inlining assets
  * Fixed #7615: Comments and "Was this page helpful?" visible when
    printing
* Fri Oct 11 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.40:
  * Updated Latvian translations
  * Fixed #7597: Social cards not using site name on home page
* Sun Sep 29 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.39:
  * Fixed #7226
    <https://github.com/squidfunk/mkdocs-material/issues/7226>: not
    staying on page when using mike's canonical versioning
* Fri Sep 27 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.38:
  * Added Albanian translations
* Fri Sep 27 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.37:
  * Added 4th and 5th level ordered list styles
  * Fixed #7548
    <https://github.com/squidfunk/mkdocs-material/issues/7548>:
    Tags have no spacing in search
* Sat Sep 21 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.36:
  * Fixed #7544: Social cards incorrectly rendering HTML entities
  * Fixed #7542: Improved support for setting custom list styles
* Sat Sep 21 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.35:
  * Fixed #7498: Search not showing for Vietnamese language
* Mon Sep  9 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.34:
  * Updated Mermaid.js to version 11 (latest)
* Mon Sep  9 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.33:
  * Fixed #7453: Incorrect position of tooltip when sorting table
* Mon Aug 19 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.32:
  * Fixed RXSS vulnerability via deep link in search results
  * Added support for fetching latest release from GitLab
* Fri Aug  2 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.31:
  * Fixed #7405: DockerHub missing images > 9.5.27 due to change in
    Alpine/APK
* Wed Jul 24 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.30:
  * Fixed #7380 <https://github.com/squidfunk/mkdocs-material/issues/7380>:
    Navigation icons disappearing on hover in Safari
  * Fixed #7367 <https://github.com/squidfunk/mkdocs-material/issues/7367>:
    Blog readtime computation includes SVG text content
* Sun Jul 14 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.29:
  * Updated Galician translations
  * Fixed #7362 <https://github.com/squidfunk/mkdocs-material/issues/7362>:
    Annotations in figure captions rendering incorrectly
* Wed Jul  3 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.28:
  * Fixed #7313 <https://github.com/squidfunk/mkdocs-material/pull/7313>:
  Improved tooltips mounted in sidebar when feature is disabled
* Sun Jun 16 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.27:
  * Updated Estonian translations
* Fri Jun  7 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.26:
  * Fixed #7232
    <https://github.com/squidfunk/mkdocs-material/issues/7232>:
    Tab switches on scroll when linking tabs (9.5.19 regression)
  * Fixed #7230
    <https://github.com/squidfunk/mkdocs-material/issues/7230>:
    Blog author avatar broken when referring to local file
* Thu May 30 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.25:
  * Fixed #7209 <https://github.com/squidfunk/mkdocs-material/issues/7209>:
    Tags plugin crashing on numeric tags
* Mon May 20 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.24:
  * Fixed #7187 <https://github.com/squidfunk/mkdocs-material/issues/7187>:
    Version selector title rendering issue
* Sat May 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.23:
  * Fixed #7183 <https://github.com/squidfunk/mkdocs-material/issues/7183>:
    Edge case in anchor navigation when using instant navigation
  * Fixed #6436 <https://github.com/squidfunk/mkdocs-material/issues/6436>:
    Version selector not showing version alias
* Tue May 14 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.22:
  * Fixed #7170 <https://github.com/squidfunk/mkdocs-material/issues/7170>:
    Copy button adds empty lines for line spans (9.5.18 regression)
  * Fixed #7160 <https://github.com/squidfunk/mkdocs-material/issues/7160>:
    Version switching doesn't stay on page (9.5.5 regression)
  * Fixed #5619 <https://github.com/squidfunk/mkdocs-material/issues/5619>:
    Links in Mermaid.js diagrams not discernible
* Sun May  5 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.21:
  * Fixed #7133 <https://github.com/squidfunk/mkdocs-material/issues/7133>:
    Ensure latest version of Mermaid.js is used
  * Fixed #7125 <https://github.com/squidfunk/mkdocs-material/issues/7125>:
    Added warning for dotfiles in info plugin
* Tue Apr 30 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.20:
  * Fixed deprecation warning in privacy plugin (9.5.19 regression)
  * Fixed #7119 <https://github.com/squidfunk/mkdocs-material/issues/7119>:
    Tags plugin emits deprecation warning (9.5.19 regression)
  * Fixed #7118 <https://github.com/squidfunk/mkdocs-material/issues/7118>:
    Social plugin crashes if fonts are disabled (9.5.19 regression)
  * Fixed #7085 <https://github.com/squidfunk/mkdocs-material/issues/7085>:
    Social plugin crashes on Windows when downloading fonts
* Thu Apr 25 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.19:
  * Updated MkDocs to 1.6 and limited version to < 2
  * Updated Docker image to latest Alpine Linux
  * Removed |setup.py|, now that GitHub fully understands |pyproject.toml|
  * Improved interop of social plugin with third-party MkDocs themes
  * Fixed #7099 <https://github.com/squidfunk/mkdocs-material/issues/7099>:
    Blog reading time not rendered correctly for Japanese
  * Fixed #7097 <https://github.com/squidfunk/mkdocs-material/issues/7097>:
    Improved resilience of tags plugin when no tags are given
  * Fixed #7090 <https://github.com/squidfunk/mkdocs-material/issues/7090>:
    Active tab indicator in nested content tabs rendering bug
* Tue Apr 16 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.18:
  * Refactored tooltips implementation to fix positioning issues
  * Fixed #7044 Rendering glitch when hovering contributor avatar
    in Chrome
  * Fixed #7043 Highlighted lines in code blocks cutoff on mobile
  * Fixed #6910 Incorrect position of tooltip for page status in
    sidebar
  * Fixed #6760 Incorrect position and overly long tooltip in
    tables
  * Fixed #6488 Incorrect position and cutoff tooltip in content
    tabs
* Wed Apr  3 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.17:
  * Updated Serbian translations
  * Fixed #7003: Confusing keyboard interaction for palette toggle
  * Fixed #7001: posts now show time by default (9.5.16 regression)
  * Fixed edge case in backport of social plugin font loading logic
* Wed Apr  3 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.16:
  * Updated Russian translations
  * Improved error handling and reporting in social plugin
  * Improved error handling and reporting in privacy plugin
  * Fixed blog plugin not allowing to use time in format strings
  * Fixed #6983: Social plugin crashes because of Google Fonts API
    change
* Sat Mar 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.15:
  * Reverted fix for transparent iframes (9.5.14)
  * Fixed #6929 <https://github.com/squidfunk/mkdocs-material/issues/6929>:
    Interference of social plugin and auto dark mode
  * Fixed #6938 <https://github.com/squidfunk/mkdocs-material/discussions/6938>:
    Giscus shows dark background in light mode (9.5.14 regression)
* Fri Mar 22 2024 Daniel Garcia <daniel.garcia@suse.com>
- Build for python3.12 now that python312-paginate exists
* Mon Mar 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.14:
  * Added support for hiding versions from selector when using mike
  * Added init system to improve signal handling in Docker image
  * Fixed edge cases in exclusion logic of info plugin
  * Fixed inability to reset pipeline in search plugin
  * Fixed syntax error in Finnish translations
  * Fixed #6917
    <https://github.com/squidfunk/mkdocs-material/issues/6917>:
    UTF-8 encoding problems in blog plugin on Windows
  * Fixed #6889
    <https://github.com/squidfunk/mkdocs-material/issues/6889>:
    Transparent iframes get background color
* Sat Mar 16 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.13:
  * Updated Slovak translations
  * Improved info plugin interop with projects plugin
  * Improved info plugin inclusion/exclusion logic
  * Fixed info plugin not gathering files recursively
  * Fixed #6750
    <https://github.com/squidfunk/mkdocs-material/issues/6750>:
    Ensure info plugin packs up all necessary files
* Sat Mar 16 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.12:
  * Fixed #6846
    <https://github.com/squidfunk/mkdocs-material/issues/6846>:
    Some meta tags removed on instant navigation (9.4.2 regression)
  * Fixed #6823
    <https://github.com/squidfunk/mkdocs-material/pull/6823>: KaTex
    not rendering on instant navigation (9.5.5 regression)
  * Fixed #6821
    <https://github.com/squidfunk/mkdocs-material/issues/6821>:
    Privacy plugin doesn't handle URLs with encoded characters
* Sat Feb 24 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.11:
  * Updated Finnish translation
* Mon Feb 19 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.10:
  * Added Bahasa Malaysia translations
  * Fixed #6783
    <https://github.com/squidfunk/mkdocs-material/issues/6783>:
    Hide continue reading link for blog posts without separators
  * Fixed #6779
    <https://github.com/squidfunk/mkdocs-material/issues/6779>:
    Incorrect positioning of integrated table of contents
* Sat Feb 10 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.9:
  * Fixed navigation pruning with tabs and sections enabled
* Wed Feb  7 2024 Dirk Müller <dmueller@suse.com>
- skip build for python 3.12
* Wed Feb  7 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.8:
  * Added Tamil translations
  * Updated Esperanto translations
  * Fixed relative images not being resolved for instant
    navigation
* Sat Feb  3 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.7:
  * Fixed #6731
    <https://github.com/squidfunk/mkdocs-material/issues/6731>:
    Small images in figures are not centered
  * Fixed #6719
    <https://github.com/squidfunk/mkdocs-material/issues/6719>:
    Instant navigation breaks table of contents (9.5.5 regression)
* Sun Jan 28 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.6:
  * Fixed #6700: Missing styles for Mermaid.js labels with Markdown
* Fri Jan 26 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.5:
  * Updated Tagalog translations
  * Updated Pillow to 10.2 to mitigate security vulnerabilities
  * Improved resilience of instant navigation
  * Fixed #6687: Updated Mermaid.js to version 10.7.0 (latest)
  * Fixed #6652: Keyboard events in custom elements captured
  * Fixed #6582: Instant navigation doesn't correctly handle
    alternate URLs
  * Fixed #6565: Instant navigation doesn't allow for `onclick`
    handlers
  * Fixed #6345: Instant navigation sometimes breaks browser back
    button
  * Fixed #6334: Instant navigation doesn't correctly position
    anchors (Safari)
  * Fixed #6275: Instant navigation doesn't correctly resolve after
    404
  * Fixed #6102: Instant navigation reloads page on same link
    navigation
* Mon Jan 15 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.4:
  * Fixed #6645: Local storage with invalid value can break site
  * Fixed #6635: Tags icons before default ignored if default is set
* Sun Jan  7 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 9.5.3:
  * Limited version range of MkDocs to < 1.6
  * Updated Macedonian translations
  * Fixed #6520: Group plugin crashes when using mike
  * Fixed #6494: Hide author's email address if disabled in
    git-authors plugin
* Mon Dec 11 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.5.2:
  * Fixed types for `slugify` settings in blog plugin config
  * Fixed #6469: Horizontal scrollbars on MathJax containers
* Fri Dec  8 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.5.1:
  * Updated Greek translations
  * Fixed #6464: Privacy plugin cannot be enabled
  * Fixed #6461: Sorting blog posts ignores time component in date
* Thu Dec  7 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.5.0:
  * Merged Insiders features of 'Goat's Horn' funding goal
  - Added privacy plugin: automatic downloading of external
    assets
  - Added support for card grids and grid layouts
  - Added support for improved tooltips
  - Added support for content tabs anchor links (deep linking)
  - Added support for automatic dark/light mode
  - Added support for document contributors
* Mon Nov 27 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.4.14:
  * Added support for linking authors in blog posts
* Mon Nov 27 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.4.13:
  * Fixed #6365: Blog plugin pagination links to previous pages
    broken
  * Fixed #5758: Updated Mermaid.js to version 10.6.1 (latest)
* Fri Nov 24 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.4.12:
  * Improved blog plugin to generate Unicode-aware slugs by default
  * Fixed non-deterministic order of categories in blog plugin
* Thu Nov 23 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.4.11:
  * Fixed #6364: Search plugin crashing when enabling theme while
    serving
  * Fixed blog plugin crashing when disabling pagination
* Mon Nov 20 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.4.10:
  * Fixed #6356: Version selector can't be disabled via mike's
    configuration
  * Fixed #6281: Navigation not rendering due to Safari bug (9.4.2
    regression)
  * Fixed #6261: Navigation expansion animates on first load
    (9.4.2 regression)
* Fri Nov 17 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.4.9:
  * Fixed #6344: Long entries cutoff in table of contents
  * Fixed #6336: Custom template for glob archive not working with
    pagination
  * Fixed #6328: Blog plugin crashes for locales with dashes, e.g.
    `pt-BR`
  * Fixed #6327: Copy-to-clipboard button doesn't trim trailing
    line feed
  * Fixed #6302: Version strings not matched when using mike, only
    aliases
  * Fixed instant navigation progress indicator for gzipped content
    in Chrome
  * Fixed rendering bug on details marker rotation in Firefox
* Mon Nov  6 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.4.8:
  * Fixed invalid local address replacement when using instant
    loading
  * Fixed #6275: Crash after navigation caused 404 when using
    instant loading
* Mon Oct 30 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.4.7:
  * Added Azerbaijani translations
* Sat Oct 14 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.4.6:
  * Updated Danish and Norwegian (Nynorsk) translations
  * Fixed #6169
    <https://github.com/squidfunk/mkdocs-material/issues/6169>:
    Blog post metadata layout overflows on small screens
* Tue Oct 10 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.4.5:
  * Fixed sidebar auto-positioning (9.4.2 regression)
  * Fixed #6166: Improve group plugin compatibility with
    Python < 3.10
  * Fixed #6157: Hiding tags does not work (9.4.3 regression)
* Sat Oct  7 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.4.4:
  * Added support for overriding text to be copied for code blocks
  * Fixed broken layout in some browsers at breakpoints when using
    zoom
  * Fixed #6132
    <https://github.com/squidfunk/mkdocs-material/issues/6132>:
    Incomplete search highlighting for code blocks in titles
* Mon Oct  2 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.4.3:
  * Added support for instant navigation progress indicator
  * Improved spacing and alignment of tags
  * Moved back-to-top button into separate partial
  * Fixed #6104: Indentation for some code blocks lost in search
  * Fixed #6094: Blog post metadata overlaps with footer on small
    screens
  * Fixed #6069: Blog plugin crashes for categories with non-ASCII
    names
* Mon Sep 25 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.4.2:
  * Updated Slovenian translations
  * Added animation to sidebar navigation expansion and collapse
  * Added support for auto-replacement of document head for instant
    navigation
  * Improved compatibility of new emoji extension with Python <
    3.10
  * Switched regex dependency to use minimal version
  * Refactored alignment and spacing of sidebar navigation
  * Fixed expansion button not focusable via keyboard in sidebar
    navigation
  * Fixed viewport offset restoration on first load when using
    instant navigation
  * Fixed accidental highlight of non-clickable elements in blog
    plugin sidebar
  * Fixed #6041: Blog plugin crashes when `nav` is defined and blog
    not included
  * Fixed #5972: Blog plugin ignores section index pages in
    paginated views
  * Fixed #5954: Repeated click on anchor ignored when using
    instant navigation
  * Fixed #5742: Keyboard navigation broken when using instant
    navigation
* Fri Sep 22 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.4.1:
  * Improved colors and contrast in dark mode
  * Improved admonition borders to match font weight
  * Switched content tabs to neutral color
* Fri Sep 22 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.4.0:
  * Added Belarusian translations
  * Added version info to entrypoint of package
  * Added emoji extension as a replacement for materialx
  * Improved slate color scheme (dark mode) - now even darker
  * Restructured project to improve development experience
  * Updated MkDocs to 1.5.3
  * Fixed #3890: Development mode crash on Linux
* Tue Sep 19 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.3.2:
  * Updated Slovenian translations
  * Updated Python dependencies in requirements to use minimum
    versions
  * Fixed #6017: Code highlighting inconsistent in Community and
    Insiders edition
  * Fixed #6001: Contributor avatars display incorrectly in Firefox
  * Fixed #6000: Blog post drafts are included in navigatio
* Tue Sep 12 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.3.1:
  * Fixed crash of group plugin when used together with hooks
* Tue Sep 12 2023 Johannes Kastl <kastl@b1-systems.de>
- rebase patch no-hatchling-requirements_txt.patch
- update to 9.3.0:
  * Improved configuration sharing between community and Insiders
    edition
  * Added experimental built-in group plugin for enabling plugins
    conditionally
  * Added new settings in tags plugin for enabling/disabling
  * Dropped support for Python 3.7 (EOL)
* Thu Sep  7 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.2.8:
  * Updated Italian and Russian translations
  * Fixed #5952: Combining blog and tags plugin leads to wrong
    links
  * Fixed #5951: Blog plugin ignores post title in metadata
  * Fixed #5949: Blog plugin ignores post linked in nav
* Thu Sep  7 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.2.7:
  * Switched dependencies to compatible release clauses
  * Removed `readtime` and `lxml` dependencies for blog plugin
  * Reduced size of Docker image to improve CI build performance
  * Fixed #5945: Incorrect footer navigation for sibling pages of
    blog
  * Fixed #5939: Page jumps when changing color palette (Firefox
    117)
  * Fixed #5901: Announcement bar reappears when using instant
    loading
  * Fixed #5824: Allow to customize styles of sequence diagrams
* Thu Sep  7 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.2.6:
  * Added Basque translations
  * Added template for simple redirects
  * Improved blog plugin interop by moving view generation to
    `on_files`
  * Fixed #5924: Social plugin still checks dependencies when
    disabled
  * Fixed #5916: Blog plugin crashes on Python 3.8 (9.2.0
    regression)
* Thu Sep  7 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.2.5:
  * Fixed error in dirty serve mode when using blog plugin
  * Fixed page title not being consistent in blog plugin pagination
  * Fixed #5899: Blog plugin pagination breaks when disabling
    directory URLs
* Thu Sep  7 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.2.4:
  * Added version to bug report name in info plugin
  * Updated Afrikaans translations
* Thu Sep  7 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.2.3:
  * Fixed blog plugin rendering wrongly with
    `markdown.extensions.toc`
  * Fixed blog plugin entrypoint generation
* Thu Sep  7 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.2.2:
  * Fixed #5880: Blog plugin failing when building a standalone
    blog
  * Fixed #5881: Blog plugin not compatible with Python < 3.10
* Thu Sep  7 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.2.1:
  * Fixed #5879: Blog plugin failing when building a standalone
    blog
  * Fixed error in blog plugin when using draft tagging on future
    date
  * Fixed error in blog plugin when toc extension is not enabled
* Wed Sep  6 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.2.0:
  * Additions and improvements
  - Added blogging support via built-in blog plugin
  - Added support for Chinese language segmentaiton in search
    plugin
  - Added support for adding custom dates to blog posts
  - Added support for paginating archive and category pages
  - Added support for annotations (outside of code blocks)
  - Added support for navigation icons
  - Added support for navigation pruning
  - Added support for navigation status
  - Added support for customizing site icons
  - Added support for customizing (code) annotation icons
  - Added focus outline to admonitions and details
  - Added prompt for bug report name to info plugin
  - Added Luxembourgish translations
  - Improved rendering of (code) annotation markers
  - Improved print styles for (code) annotations
  - Improved customizability of navigation tabs
  - Improved interop of plugins with external tools like mike
  - Improved interop of blog plugin with awesome pages plugin
  - Improved header partial by moving buttons into separate
    partials
  - Improved clarity of `site_url` warning in social plugin
  - Improved blog plugin to automatically setup directory
    structure
  - Switched info plugin to `importlib` to mitigate deprecations
  - Automatically download ResizeObserver polyfill when necessary
  - Automatically add iframe-worker polyfill when necessary in
    offline plugin
  - Automatically focus and bring up keyboard on touch devices
  - Updated Serbo-Croatian translations
  - Updated MkDocs to 1.5.2
  * Removals
  - Removed Universal Analytics integration
  - Removed ancient polyfills to reduce size of bundled
    JavaScript by 20%%
  - Removed necessity for `Array.flat` and `Array.flatMap`
    polyfill
  - Removed announcement bar button when JavaScript is not
    available
  * Fixes
  - Fixed rendering of tags when announcement bar is present
  - Fixed tags plugin rendering pages excluded by other plugins
  - Fixed #5132: Blog plugin requires `nav` entry in `mkdocs.yml`
  - Fixed #5599: Insufficient contrast for default link color
  - Fixed #5715: Blog plugin missing integrated table of contents
    in pagination
  - Fixed #5806: Version selector not hoverable on some Android
    devices
  - Fixed #5826: Blog post drafts with tags show up in tags index
* Tue Aug  1 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.1.21:
  * Fixed MkDocs 1.4 compat issue in social plugin (9.1.20
    regression)
* Thu Jul 27 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.1.20:
  * Updated Sanskrit translations
  * Fixed deprecation warnings for social plugin
* Tue Jul 18 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.1.19:
  * Added support for MkDocs 1.5+
  * Fixed #5699: Improve error reporting in social plugin
* Mon Jul  3 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.1.18:
  * Updated Danish translations
  * Added support for installing user requirements in Docker image
  * Fixed #5655: Search separator with lookbehind breaks
    highlighting
* Mon Jun 26 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.1.17:
  * Fixed #5633: Code annotations with nested lists incorrectly
    mounted
  * Fixed #5628: Regression in new social plugin configuration
    scheme
* Fri Jun 16 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.1.16:
  * Updated Indonesian translations
  * Ensure scroll bar follows color scheme of operating system
* Mon May 29 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.1.15:
  * Fixed #5566: Indicate color scheme to operating system
  * Fixed #5565: Update `Dockerfile` to latest version of base
    image
  * Fixed #5554: Add additional version tags (`9`, `9.1`) to Docker
    image
  * Fixed #5536: Strip tags of ARIA labels in table of contents
* Mon May 22 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.1.14:
  * Updated Armenian and Greek translations
* Tue May 16 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.1.13:
  * Fixed #5517: Social plugin crashes for some fonts (e.g. Open
    Sans)
* Fri May 12 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.1.12:
  * Updated Bengali (Bengal) translations
  * Fixed #5503: Docker image publish errors on uppercase
    characters
  * Fixed #5407: Auto-pause media when in hidden content tabs
* Tue May  9 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.1.11:
  * Fixed #5487: Social plugin crashes without options
    (9.1.10 regression)
* Tue May  9 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.1.10:
  * Added `cards_layout_options` setting for social cards
  * Deprecated `cards_color` and `cards_font` setting for social
    cards
* Fri May  5 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Tue May  2 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.1.9:
  * Added Telulugu, Kannada and Sanskrit translations
  * Fixed #5428: Fixed margins for light/dark mode images in
    figures
  * Fixed #5420: Social plugin crashing for some specific Google
    Fonts
  * Fixed #5160: Instant loading makes code annotations jump (9.1.1
    regression)
  * Fixed #4920: Social plugin not loading logo from custom icon
    set
  * Fixed social plugin crashing when only code font is specified
* Mon Apr 24 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.1.8:
  * Fixed #5417: Theme breaks when `palette` is not defined (9.1.7
    regression)
* Sat Apr 22 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.1.7:
  * Updated Persian (Farsi) and Turkish translations
  * Fixed #5401: Added missing flag to disable built-in tags plugin
  * Fixed #5206: Ensure defaults are set for primary and accent
    colors
  * Fixed unnecessary inclusion of palette CSS when unused
* Thu Apr 13 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.1.6
  * Updated Persian (Farsi) translations
  * Fixed #5300: Boxes in Mermaid sequence diagrams not
    color-abiding
* Thu Apr 13 2023 Johannes Kastl <kastl@b1-systems.de>
- really add proper Requires for plugins...
* Tue Apr  4 2023 Johannes Kastl <kastl@b1-systems.de>
- add Requires needed for plugins
* Mon Apr  3 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 9.1.5:
  * Updated Lithuanian and Japanese translations
  * Updated Mermaid.js to version 9.4.3
  * Fixed #5290: Footer previous/next labels cut-off for short page
    titles
- update to 9.1.4:
  * Fixed #5239: Instant loading breaks anchors in details
    (9.1.1 regression)
  * Fixed #5211: Anchor following not working for Chinese
    (9.1.2 regression)
* Tue Mar 28 2023 Matej Cepl <mcepl@suse.com>
- Add no-hatchling-requirements_txt.patch, which manually
  create project.dependencies in pyproject.toml instead of
  using hatch_requirements_txt module. This is a brutal
  hack, but otherwise (see sr#1072844 for details) we need
  python-hatch_requirements_txt which pulls in excessive number
  of packages (starting with python-conincidence, python-whey,
  python-domdf-python-tools, and many others). Until we have
  these in openSUSE, we should stay with this hand-managed patch.
* Sat Mar 18 2023 Johannes Kastl <kastl@b1-systems.de>
- new package python-mkdocs-material
